@@ -32,36 +32,93 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
 import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
 
 /**
- * <p>
- * Checks that <a href=
- * "https://www.oracle.com/technetwork/java/javase/documentation/index-137868.html#firstsentence">
+ *<p>
+ * Checks that
+ * <a href="https://www.oracle.com/technetwork/java/javase/documentation/index-137868.html#firstsentence">
  * Javadoc summary sentence</a> does not contain phrases that are not recommended to use.
- * Check also violate javadoc that does not contain first sentence.
- * By default Check validate that first sentence is not empty:</p><br>
+ * Summaries that contain only the {@code {@inheritDoc}} tag are skipped.
+ * Check also violate Javadoc that does not contain first sentence.
+ * </p>
+ * <ul>
+ * <li>
+ * Property {@code violateExecutionOnNonTightHtml} - Control when to print violations
+ * if the Javadoc being examined by this check violates the tight html rules defined at
+ * <a href="https://checkstyle.org/writingjavadocchecks.html#Tight-HTML_rules">Tight-HTML Rules</a>.
+ * Default value is {@code false}.
+ * </li>
+ * <li>
+ * Property {@code forbiddenSummaryFragments} - Specify the regexp for forbidden summary fragments.
+ * Default value is {@code "^$" (empty)}.
+ * </li>
+ * <li>
+ * Property {@code period} - Specify the period symbol at the end of first javadoc sentence.
+ * Default value is {@code "."}.
+ * </li>
+ * </ul>
+ * <p>
+ * By default Check validate that first sentence is not empty and first sentence is not missing:
+ * </p>
  * <pre>
  * &lt;module name=&quot;SummaryJavadocCheck&quot;/&gt;
  * </pre>
- *
- * <p>To ensure that summary do not contain phrase like "This method returns",
- *  use following config:
- *
+ * <p>
+ * Example of {@code {@inheritDoc}} without summary.
+ * </p>
  * <pre>
- * &lt;module name=&quot;SummaryJavadocCheck&quot;&gt;
- *     &lt;property name=&quot;forbiddenSummaryFragments&quot;
- *     value=&quot;^This method returns.*&quot;/&gt;
+ * public class Test extends Exception {
+ * //Valid
+ *   &#47;**
+ *    * {&#64;inheritDoc}
+ *    *&#47;
+ *   public String ValidFunction(){
+ *     return "";
+ *   }
+ *   //Violation
+ *   &#47;**
+ *    *
+ *    *&#47;
+ *   public String InvalidFunction(){
+ *     return "";
+ *   }
+ * }
+ * </pre>
+ * <p>
+ * To ensure that summary do not contain phrase like "This method returns",
+ * use following config:
+ * </p>
+ * <pre>
+ * &lt;module name="SummaryJavadocCheck"&gt;
+ *   &lt;property name="forbiddenSummaryFragments"
+ *     value="^This method returns.*"/&gt;
  * &lt;/module&gt;
  * </pre>
  * <p>
- * To specify period symbol at the end of first javadoc sentence - use following config:
+ * To specify period symbol at the end of first javadoc sentence:
  * </p>
  * <pre>
- * &lt;module name=&quot;SummaryJavadocCheck&quot;&gt;
- *     &lt;property name=&quot;period&quot;
- *     value=&quot;period&quot;/&gt;
+ * &lt;module name="SummaryJavadocCheck"&gt;
+ *   &lt;property name="period" value="。"/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <p>
+ * Example of period property.
+ * </p>
+ * <pre>
+ * public class TestClass {
+ *   &#47;**
+ *   * This is invalid java doc.
+ *   *&#47;
+ *   void invalidJavaDocMethod() {
+ *   }
+ *   &#47;**
+ *   * This is valid java doc。
+ *   *&#47;
+ *   void validJavaDocMethod() {
+ *   }
+ * }
+ * </pre>
  *
- *
+ * @since 6.0
  */
 @StatelessCheck
 public class SummaryJavadocCheck extends AbstractJavadocCheck {
@@ -97,14 +154,15 @@ public class SummaryJavadocCheck extends AbstractJavadocCheck {
                     JavadocTokenTypes.WS))
     );
 
-    /** Regular expression for forbidden summary fragments. */
+    /** Specify the regexp for forbidden summary fragments. */
     private Pattern forbiddenSummaryFragments = CommonUtil.createPattern("^$");
 
-    /** Period symbol at the end of first javadoc sentence. */
+    /** Specify the period symbol at the end of first javadoc sentence. */
     private String period = PERIOD;
 
     /**
-     * Sets custom value of regular expression for forbidden summary fragments.
+     * Setter to specify the regexp for forbidden summary fragments.
+     *
      * @param pattern a pattern.
      */
     public void setForbiddenSummaryFragments(Pattern pattern) {
@@ -112,7 +170,8 @@ public class SummaryJavadocCheck extends AbstractJavadocCheck {
     }
 
     /**
-     * Sets value of period symbol at the end of first javadoc sentence.
+     * Setter to specify the period symbol at the end of first javadoc sentence.
+     *
      * @param period period's value.
      */
     public void setPeriod(String period) {
