@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2019 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -29,23 +29,19 @@ import static com.puppycrawl.tools.checkstyle.PackageObjectFactory.PACKAGE_SEPAR
 import static com.puppycrawl.tools.checkstyle.PackageObjectFactory.STRING_SEPARATOR;
 import static com.puppycrawl.tools.checkstyle.PackageObjectFactory.UNABLE_TO_INSTANTIATE_EXCEPTION_MESSAGE;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.fail;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.when;
 
 import java.io.File;
-import java.io.IOException;
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
-import java.net.URLClassLoader;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.LinkedHashSet;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Set;
 
 import org.junit.Test;
@@ -324,18 +320,6 @@ public class PackageObjectFactoryTest {
         assertNotNull("Check should not be null when creating module from name", check);
     }
 
-    @Test
-    @SuppressWarnings("unchecked")
-    public void testGenerateThirdPartyNameToFullModuleNameWithException() throws Exception {
-        final URLClassLoader classLoader = mock(URLClassLoader.class);
-        when(classLoader.getURLs()).thenThrow(IOException.class);
-        final Method method = factory.getClass().getDeclaredMethod(
-                "generateThirdPartyNameToFullModuleName", ClassLoader.class);
-        method.setAccessible(true);
-        final int size = ((Map<String, String>) method.invoke(factory, classLoader)).size();
-        assertEquals("Invalid map size", 0, size);
-    }
-
     @Test
     public void testJoinPackageNamesWithClassName() throws Exception {
         final Class<PackageObjectFactory> clazz = PackageObjectFactory.class;
@@ -357,8 +341,19 @@ public class PackageObjectFactoryTest {
         final Field field = packageObjectFactoryClass.getDeclaredField("NAME_TO_FULL_MODULE_NAME");
         field.setAccessible(true);
         final Collection<String> canonicalNames = ((Map<String, String>) field.get(null)).values();
-        assertFalse("Invalid canonical name", classes.stream()
-                .anyMatch(clazz -> !canonicalNames.contains(clazz.getCanonicalName())));
+
+        final Optional<Class<?>> optional1 = classes.stream()
+                .filter(clazz -> !canonicalNames.contains(clazz.getCanonicalName())).findFirst();
+        if (optional1.isPresent()) {
+            fail("Invalid canonical name: " + optional1.get());
+        }
+        final Optional<String> optional2 = canonicalNames.stream().filter(canonicalName -> {
+            return classes.stream().map(Class::getCanonicalName)
+                    .noneMatch(clssCanonicalName -> clssCanonicalName.equals(canonicalName));
+        }).findFirst();
+        if (optional2.isPresent()) {
+            fail("Invalid class: " + optional2.get());
+        }
     }
 
     @Test
