@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2019 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -33,6 +33,7 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -46,9 +47,11 @@ import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 import com.puppycrawl.tools.checkstyle.api.Context;
+import com.puppycrawl.tools.checkstyle.api.FileContents;
 import com.puppycrawl.tools.checkstyle.api.FileText;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.checks.blocks.LeftCurlyCheck;
+import com.puppycrawl.tools.checkstyle.checks.coding.EmptyStatementCheck;
 import com.puppycrawl.tools.checkstyle.checks.coding.HiddenFieldCheck;
 import com.puppycrawl.tools.checkstyle.checks.indentation.CommentsIndentationCheck;
 import com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocPackageCheck;
@@ -56,6 +59,7 @@ import com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocParagraphCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.ConstantNameCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.MemberNameCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.TypeNameCheck;
+import com.puppycrawl.tools.checkstyle.filters.SuppressWithNearbyCommentFilter;
 import com.puppycrawl.tools.checkstyle.filters.SuppressionCommentFilter;
 import com.puppycrawl.tools.checkstyle.filters.SuppressionXpathFilter;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
@@ -175,7 +179,6 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         final DefaultConfiguration config = new DefaultConfiguration("default config");
         treeWalker.setTabWidth(1);
         treeWalker.configure(config);
-        treeWalker.setCacheFile(temporaryFolder.newFile().getPath());
 
         assertEquals("Invalid setter result", 1,
                 (int) Whitebox.getInternalState(treeWalker, "tabWidth"));
@@ -213,6 +216,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
             new ArrayList<>(Arrays.asList("package com.puppycrawl.tools.checkstyle;", "",
                 "error public class InputTreeWalkerFileWithViolation {}"));
         final FileText fileText = new FileText(file, lines);
+        treeWalker.setFileContents(new FileContents(fileText));
         try {
             treeWalker.processFiltered(file, fileText);
             fail("Exception expected");
@@ -261,6 +265,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         final List<String> lines = new ArrayList<>();
         lines.add(" classD a {} ");
         final FileText fileText = new FileText(file, lines);
+        treeWalker.setFileContents(new FileContents(fileText));
         try {
             treeWalker.processFiltered(file, fileText);
             fail("Exception is expected");
@@ -284,6 +289,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         final List<String> lines = new ArrayList<>();
         lines.add(" class a%$# {} ");
         final FileText fileText = new FileText(file, lines);
+        treeWalker.setFileContents(new FileContents(fileText));
         try {
             treeWalker.processFiltered(file, fileText);
             fail("Exception is expected");
@@ -295,26 +301,6 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         }
     }
 
-    @Test
-    public void testRequiredTokenIsNotInDefaultTokens() throws Exception {
-        final DefaultConfiguration checkConfig =
-            createModuleConfig(RequiredTokenIsNotInDefaultsCheck.class);
-        final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
-
-        try {
-            final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
-            verify(checkConfig, pathToEmptyFile, expected);
-            fail("CheckstyleException is expected");
-        }
-        catch (CheckstyleException ex) {
-            assertTrue("Error message is unexpected",
-                    ex.getMessage().startsWith("cannot initialize module"
-                + " com.puppycrawl.tools.checkstyle.TreeWalker - Token \""
-                + TokenTypes.ASSIGN + "\" from required"
-                + " tokens was not found in default tokens list in check"));
-        }
-    }
-
     @Test
     public void testRequiredTokenIsEmptyIntArray() throws Exception {
         final DefaultConfiguration checkConfig =
@@ -340,56 +326,6 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         assertTrue("No checks -> No parsing", checks.isEmpty());
     }
 
-    @Test
-    public void testBehaviourWithOnlyOrdinaryChecks() throws Exception {
-        final TreeWalker treeWalker = new TreeWalker();
-        treeWalker.configure(createModuleConfig(TypeNameCheck.class));
-        final PackageObjectFactory factory = new PackageObjectFactory(
-                new HashSet<>(), Thread.currentThread().getContextClassLoader());
-        treeWalker.setModuleFactory(factory);
-        treeWalker.setupChild(createModuleConfig(TypeNameCheck.class));
-        final File file = temporaryFolder.newFile("file.java");
-        final List<String> lines = new ArrayList<>();
-        lines.add(" class a%$# {} ");
-        final FileText fileText = new FileText(file, lines);
-
-        try {
-            treeWalker.processFiltered(file, fileText);
-            fail("file is not compilable, exception is expected");
-        }
-        catch (CheckstyleException exception) {
-            final String message =
-                    "TokenStreamRecognitionException occurred while parsing file";
-            assertTrue("Error message is unexpected",
-                    exception.getMessage().contains(message));
-        }
-    }
-
-    @Test
-    public void testBehaviourWithOnlyCommentChecks() throws Exception {
-        final TreeWalker treeWalker = new TreeWalker();
-        treeWalker.configure(createModuleConfig(CommentsIndentationCheck.class));
-        final PackageObjectFactory factory = new PackageObjectFactory(
-                new HashSet<>(), Thread.currentThread().getContextClassLoader());
-        treeWalker.setModuleFactory(factory);
-        treeWalker.setupChild(createModuleConfig(CommentsIndentationCheck.class));
-        final File file = temporaryFolder.newFile("file.java");
-        final List<String> lines = new ArrayList<>();
-        lines.add(" class a%$# {} ");
-        final FileText fileText = new FileText(file, lines);
-
-        try {
-            treeWalker.processFiltered(file, fileText);
-            fail("file is not compilable, exception is expected");
-        }
-        catch (CheckstyleException exception) {
-            final String message =
-                    "TokenStreamRecognitionException occurred while parsing file";
-            assertTrue("Error message is unexpected",
-                    exception.getMessage().contains(message));
-        }
-    }
-
     @Test
     public void testBehaviourWithOrdinaryAndCommentChecks() throws Exception {
         final TreeWalker treeWalker = new TreeWalker();
@@ -404,6 +340,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         final List<String> lines = new ArrayList<>();
         lines.add(" class a%$# {} ");
         final FileText fileText = new FileText(file, lines);
+        treeWalker.setFileContents(new FileContents(fileText));
 
         try {
             treeWalker.processFiltered(file, fileText);
@@ -417,6 +354,26 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         }
     }
 
+    @Test
+    public void testSetupChild() throws Exception {
+        final TreeWalker treeWalker = new TreeWalker();
+        final PackageObjectFactory factory = new PackageObjectFactory(
+                new HashSet<>(), Thread.currentThread().getContextClassLoader());
+        treeWalker.setModuleFactory(factory);
+        treeWalker.setTabWidth(99);
+        treeWalker.finishLocalSetup();
+
+        final Configuration config = new DefaultConfiguration(
+                XpathFileGeneratorAstFilter.class.getName());
+
+        treeWalker.setupChild(config);
+
+        final Set<TreeWalkerFilter> filters = Whitebox.getInternalState(treeWalker, "filters");
+        final int tabWidth = Whitebox.getInternalState(filters.iterator().next(), "tabWidth");
+
+        assertEquals("expected tab width", 99, tabWidth);
+    }
+
     @Test
     public void testBehaviourWithChecksAndFilters() throws Exception {
         final DefaultConfiguration filterConfig =
@@ -453,8 +410,6 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         treeWalker.finishLocalSetup();
 
         final Context context = Whitebox.getInternalState(treeWalker, "childContext");
-        assertEquals("Classloader object differs from expected",
-                contextClassLoader, context.get("classLoader"));
         assertEquals("Severity differs from expected",
                 "error", context.get("severity"));
         assertEquals("Tab width differs from expected",
@@ -538,6 +493,25 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         verify(checkerConfig, filePath, expected);
     }
 
+    @Test
+    public void testExternalResourceFiltersWithNoExternalResource() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(EmptyStatementCheck.class);
+        final DefaultConfiguration filterConfig =
+                createModuleConfig(SuppressWithNearbyCommentFilter.class);
+        final DefaultConfiguration treeWalkerConfig = createModuleConfig(TreeWalker.class);
+        treeWalkerConfig.addChild(checkConfig);
+        treeWalkerConfig.addChild(filterConfig);
+
+        final DefaultConfiguration checkerConfig = createRootConfig(treeWalkerConfig);
+        final File cacheFile = temporaryFolder.newFile();
+        checkerConfig.addAttribute("cacheFile", cacheFile.getPath());
+
+        final String filePath = temporaryFolder.newFile("file.java").getPath();
+        final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
+
+        verify(checkerConfig, filePath, expected);
+    }
+
     private static class BadJavaDocCheck extends AbstractCheck {
 
         @Override
@@ -632,25 +606,6 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
 
     }
 
-    private static class RequiredTokenIsNotInDefaultsCheck extends AbstractCheck {
-
-        @Override
-        public int[] getRequiredTokens() {
-            return new int[] {TokenTypes.ASSIGN};
-        }
-
-        @Override
-        public int[] getDefaultTokens() {
-            return new int[] {TokenTypes.ANNOTATION};
-        }
-
-        @Override
-        public int[] getAcceptableTokens() {
-            return CommonUtil.EMPTY_INT_ARRAY;
-        }
-
-    }
-
     private static class RequiredTokenIsEmptyIntArray extends AbstractCheck {
 
         @Override
