@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2019 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -34,6 +34,7 @@ import org.powermock.reflect.Whitebox;
 import antlr.CommonHiddenStreamToken;
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
+import com.puppycrawl.tools.checkstyle.DetailAstImpl;
 import com.puppycrawl.tools.checkstyle.JavaParser;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -71,6 +72,7 @@ public class VisibilityModifierCheckTest
             "41:29: " + getCheckMessage(MSG_KEY, "sWeird"),
             "43:19: " + getCheckMessage(MSG_KEY, "sWeird2"),
             "77:20: " + getCheckMessage(MSG_KEY, "someValue"),
+            "80:11: " + getCheckMessage(MSG_KEY, "fSerialVersionUID"),
         };
         verify(checkConfig, getPath("InputVisibilityModifierInner.java"), expected);
     }
@@ -131,6 +133,34 @@ public class VisibilityModifierCheckTest
             "34:20: " + getCheckMessage(MSG_KEY, "value"),
             "36:24: " + getCheckMessage(MSG_KEY, "bValue"),
             "37:31: " + getCheckMessage(MSG_KEY, "longValue"),
+            "41:19: " + getCheckMessage(MSG_KEY, "C_D_E"),
+        };
+        verify(checkConfig, getPath("InputVisibilityModifierImmutable.java"), expected);
+    }
+
+    @Test
+    public void testAllowPublicFinalFieldsInImmutableClassWithNonCanonicalClasses()
+            throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(VisibilityModifierCheck.class);
+        checkConfig.addAttribute("allowPublicImmutableFields", "true");
+        checkConfig.addAttribute("immutableClassCanonicalNames", "String, Integer, Byte, "
+                + "Character, Short, Boolean, Long, Double, Float, StackTraceElement, BigInteger, "
+                + "BigDecimal, File, Locale, UUID, URL, URI, Inet4Address, Inet6Address, "
+                + "InetSocketAddress");
+        final String[] expected = {
+            "12:39: " + getCheckMessage(MSG_KEY, "includes"),
+            "13:39: " + getCheckMessage(MSG_KEY, "excludes"),
+            "14:35: " + getCheckMessage(MSG_KEY, "notes"),
+            "15:29: " + getCheckMessage(MSG_KEY, "money"),
+            "16:23: " + getCheckMessage(MSG_KEY, "list"),
+            "32:35: " + getCheckMessage(MSG_KEY, "uri"),
+            "33:35: " + getCheckMessage(MSG_KEY, "file"),
+            "34:20: " + getCheckMessage(MSG_KEY, "value"),
+            "35:35: " + getCheckMessage(MSG_KEY, "url"),
+            "36:24: " + getCheckMessage(MSG_KEY, "bValue"),
+            "37:31: " + getCheckMessage(MSG_KEY, "longValue"),
+            "41:19: " + getCheckMessage(MSG_KEY, "C_D_E"),
         };
         verify(checkConfig, getPath("InputVisibilityModifierImmutable.java"), expected);
     }
@@ -154,6 +184,7 @@ public class VisibilityModifierCheckTest
             "35:35: " + getCheckMessage(MSG_KEY, "url"),
             "36:24: " + getCheckMessage(MSG_KEY, "bValue"),
             "37:31: " + getCheckMessage(MSG_KEY, "longValue"),
+            "41:19: " + getCheckMessage(MSG_KEY, "C_D_E"),
             };
         verify(checkConfig, getPath("InputVisibilityModifierImmutable.java"), expected);
     }
@@ -186,6 +217,7 @@ public class VisibilityModifierCheckTest
             "35:35: " + getCheckMessage(MSG_KEY, "url"),
             "36:24: " + getCheckMessage(MSG_KEY, "bValue"),
             "37:31: " + getCheckMessage(MSG_KEY, "longValue"),
+            "41:19: " + getCheckMessage(MSG_KEY, "C_D_E"),
         };
         verify(checkConfig, getPath("InputVisibilityModifierImmutable.java"), expected);
     }
@@ -387,7 +419,7 @@ public class VisibilityModifierCheckTest
     @Test
     public void testWrongTokenType() {
         final VisibilityModifierCheck obj = new VisibilityModifierCheck();
-        final DetailAST ast = new DetailAST();
+        final DetailAstImpl ast = new DetailAstImpl();
         ast.initialize(new CommonHiddenStreamToken(TokenTypes.CLASS_DEF, "class"));
         try {
             obj.visitToken(ast);
@@ -459,11 +491,23 @@ public class VisibilityModifierCheckTest
             new File(getPath("InputVisibilityModifierIsStarImport.java")),
             JavaParser.Options.WITHOUT_COMMENTS).getNextSibling();
         final VisibilityModifierCheck check = new VisibilityModifierCheck();
-        final Method isStarImport = Whitebox.getMethod(VisibilityModifierCheck.class,
+        final Method method = Whitebox.getMethod(VisibilityModifierCheck.class,
             "isStarImport", DetailAST.class);
 
         assertTrue("Should return true when star import is passed",
-            (boolean) isStarImport.invoke(check, importAst));
+            (boolean) method.invoke(check, importAst));
+    }
+
+    @Test
+    public void testPackageClassName() throws Exception {
+        final DefaultConfiguration checkConfig =
+            createModuleConfig(VisibilityModifierCheck.class);
+        checkConfig.addAttribute("immutableClassCanonicalNames", "PackageClass");
+        checkConfig.addAttribute("allowPublicImmutableFields", "true");
+        final String[] expected = {
+        };
+        verify(checkConfig, getNonCompilablePath("InputVisibilityModifierPackageClassName.java"),
+                expected);
     }
 
 }
