@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2019 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -34,6 +34,26 @@ public class AbbreviationAsWordInNameCheckTest extends AbstractModuleTestSupport
         return "com/puppycrawl/tools/checkstyle/checks/naming/abbreviationaswordinname";
     }
 
+    @Test
+    public void testDefault() throws Exception {
+        final DefaultConfiguration checkConfig =
+            createModuleConfig(AbbreviationAsWordInNameCheck.class);
+        final int expectedCapitalCount = 4;
+
+        final String[] expected = {
+            "9: " + getWarningMessage("FactoryWithBADNAme", expectedCapitalCount),
+            "12: " + getWarningMessage("AbstractCLASSName", expectedCapitalCount),
+            "32: " + getWarningMessage("AbstractINNERRClass", expectedCapitalCount),
+            "37: " + getWarningMessage("WellNamedFACTORY", expectedCapitalCount),
+            "38: " + getWarningMessage("marazmaticMETHODName", expectedCapitalCount),
+            "39: " + getWarningMessage("marazmaticVARIABLEName", expectedCapitalCount),
+            "40: " + getWarningMessage("MARAZMATICVariableName", expectedCapitalCount),
+            "58: " + getWarningMessage("serialNUMBER", expectedCapitalCount),
+        };
+
+        verify(checkConfig, getPath("InputAbbreviationAsWordInNameType.java"), expected);
+    }
+
     @Test
     public void testTypeNamesForThreePermittedCapitalLetters() throws Exception {
         final DefaultConfiguration checkConfig =
@@ -235,6 +255,25 @@ public class AbbreviationAsWordInNameCheckTest extends AbstractModuleTestSupport
                 getPath("InputAbbreviationAsWordInNameOverridableMethod.java"), expected);
     }
 
+    @Test
+    public void testOverriddenMethod()
+            throws Exception {
+        final DefaultConfiguration checkConfig =
+            createModuleConfig(AbbreviationAsWordInNameCheck.class);
+        checkConfig.addAttribute("ignoreOverriddenMethods", "false");
+        final int expectedCapitalCount = 4;
+
+        final String[] expected = {
+            "6: " + getWarningMessage("serialNUMBER", expectedCapitalCount),
+            "14: " + getWarningMessage("oveRRRRRrriddenMethod", expectedCapitalCount),
+            "22: " + getWarningMessage("oveRRRRRrriddenMethod", expectedCapitalCount),
+            "34: " + getWarningMessage("oveRRRRRrriddenMethod", expectedCapitalCount),
+        };
+
+        verify(checkConfig,
+                getPath("InputAbbreviationAsWordInNameOverridableMethod.java"), expected);
+    }
+
     @Test
     public void testTypeNamesForZeroPermittedCapitalLetter() throws Exception {
         final DefaultConfiguration checkConfig =
